@@ -1,31 +1,35 @@
 /*
- * Copyright James Morse Y2K+1
+ * Copyright James Morse Y2K+1, +3
  * This is GPLed software 
  * please read COPYING
  *
  */
 
-#include <term.h>
+#include <unistd.h>
+#include <termios.h>
 #include "kb.h"
 
-void init_kb ()
+static struct termios init_setting, new_setting;
+static int peek_char = -1;
+
+void init_kb()
 {
-	tcgetattr (0, &init_setting);
+	tcgetattr(0, &init_setting);
 	new_setting = init_setting;
-	new_setting.c_lflag &= -ICANON;
-	new_setting.c_lflag &= -ECHO;
-	new_setting.c_lflag &= -ISIG;
+	new_setting.c_lflag &= ~ICANON;
+	new_setting.c_lflag &= ~ECHO;
+	new_setting.c_lflag &= ~ISIG;
 	new_setting.c_cc[VMIN] = 1;
 	new_setting.c_cc[VTIME] = 0;
 	tcsetattr(0, TCSANOW, &new_setting);
 }
 
-void close_kb ()
+void close_kb()
 {
-	tcsetattr (0, TCSANOW, &init_setting);
+	tcsetattr(0, TCSANOW, &init_setting);
 }
 
-int kb_hit ()
+int kb_hit()
 {
 	char ch;
 	int nread;
@@ -34,10 +38,10 @@ int kb_hit ()
 		return 1;
 	
 	new_setting.c_cc[VMIN] = 0;
-	tcsetattr (0, TCSANOW, &new_setting);
+	tcsetattr(0, TCSANOW, &new_setting);
 	nread = read (0, &ch, 1);
 	new_setting.c_cc[VMIN] = 1;
-	tcsetattr (0, TCSANOW, &new_setting);
+	tcsetattr(0, TCSANOW, &new_setting);
 	
 	if (nread == 1)
 	{
@@ -47,7 +51,7 @@ int kb_hit ()
 	return 0;
 }
 
-int read_kb ()
+int read_kb()
 {
 	char ch;
 	
@@ -57,6 +61,7 @@ int read_kb ()
 		peek_char = -1;
 		return ch;
 	}
-	read (0, &ch, 1);
+	read(0, &ch, 1);
 	return 0;
 }
+
