@@ -1,21 +1,24 @@
 /*
- * Copyright James Morse Y2K+1
+ * Copyright James Morse Y2K +1, +2, +3
  * This is GPLed software 
  * please read COPYING
  *
  */
 
-// start keyboard stuff
 #ifndef KB_H
 #define KB_H 
 
-static struct termios init_setting, new_setting;
-static int peek_char = -1;
-
+/* get the key board the way we like it */
 void init_kb ();
+
+/* put it back how we found it */
 void close_kb ();
+
+/* did the user hit a key? */
 int kb_hit ();
+
+/* what was it? */
 int read_kb ();
 
 #endif /* KB_H */
-// end keyboard stuff
+
